Portal:Current events/January 2023 - Wikipedia

Jump to content

# Portal: Current events/January 2023

Add languages

Add links
From Wikipedia, the free encyclopedia
< Portal:Current events

January 2023 was the first month of the current common year. The month, which began on a Sunday, ended on a Tuesday after 31 days.

## Portal:Current events[edit]

This is an archived version of Wikipedia's Current events Portal from January 2023.

January 1, 2023 (2023-01-01) (Sunday)

Armed conflicts and attacks

- Afghanistan conflict
  - Islamic State–Taliban conflict
    - 2023 Kabul airport bombing
      - Several people are killed by an Islamic State bombing at a checkpoint outside the military airport in Kabul. (Al Jazeera)
- Syrian civil war
  - Israel's role in the Syrian civil war
    - Two soldiers are killed during a series of Israeli airstrikes at Damascus International Airport. (Al Jazeera)
- Kashmir conflict
  - 2023 Rajouri attacks
    - Four civilians are killed and six others injured when two gunmen open fire against Hindu people's homes in Rajouri district, Jammu and Kashmir. (India Today)
- Mexican drug war
  - 2023 Ciudad Juárez prison attack
    - Ten prison officers and four inmates are killed in an armed attack on a prison in Ciudad Juárez, Chihuahua, Mexico, in which 24 prisoners escaped. (AFP via Deccan Herald)
- Israeli–Palestinian conflict
  - Two Palestinians are killed and three more injured during confrontations with Israeli soldiers who stormed Kafr Dan to demolish the homes of two Palestinians killed in a shootout at a checkpoint in Jenin several months ago. (Al Jazeera)

Business and economy

- 2021–2023 inflation surge
  - Canadian property bubble
    - Canada enacts a law prohibiting foreigners, except for immigrants and permanent residents, from acquiring residential areas in the country for two years in response to a real-estate bubble. (CNN Business)

Disasters and accidents

- At least nine people are killed and many others are injured during a stampede at a concert in Kampala, Uganda. (Al Jazeera)

Health and environment

- COVID-19 pandemic
  - Travel during the COVID-19 pandemic
    - Australia and Canada announce that they will require travelers from China to present a negative COVID-19 test in order to enter their countries beginning on January 5. (CTV News) (Sydney Morning Herald)
- Climate change in the United Kingdom
  - The British arm of climate protest group Extinction Rebellion announces it will "temporarily" shift away from using public disruption as a primary tactic. (Reuters)

Law and crime

- Three officers with the New York City Police Department are wounded in a machete attack during New Year's Eve celebrations in Times Square. The suspect, a 19-year-old male from Maine, is also wounded and has been arrested, with jihadist motives being suspected. (NBC News)

Politics and elections

- Enlargement of the eurozone
  - Croatia and the euro
    - Croatia changes its national currency from the kuna to the euro to become 20th member state of the Eurozone, and joins the European passport-free zone, the Schengen Area. (AFP via Macau Business)
- Third inauguration of Luiz Inácio Lula da Silva
  - Luiz Inácio Lula da Silva is sworn in as President of Brazil for the third time in his political career. (Télam)

Science and technology

- 2023 Philippine airspace closure
  - The Civil Aviation Authority of the Philippines closes the country's airspace for nearly six hours due to a power outage in its air traffic management center, affecting more than 280 commercial flights and more than 56,000 passengers. (Bloomberg)

January 2, 2023 (2023-01-02) (Monday)

Armed conflicts and attacks

- Kashmir conflict
  - 2023 Rajouri attacks
    - Two children are killed and four other people are injured by an explosion outside the home of one of the four Hindus who were killed yesterday in Rajouri district, Jammu and Kashmir, India. (The Hindu)
- Mali War
  - Two firefighters and three civilians are killed in an armed attack by Islamist insurgents along a highway between Bamako and Ségou. (AFP via Barron's)
- Protests continue for a fifth day in Las Anod, Somaliland, with protesters demanding that the city be governed by Puntland instead of by Somaliland. Twenty people are killed in clashes between protestors and security forces. (Africanews)

Disasters and accidents

- 2023 Gold Coast mid-air collision
  - Four people are killed and eight others are injured when two helicopters collide near the Sea World theme park in Gold Coast, Queensland, Australia. (ABC News Australia)

Health and environment

- Malawi suspends the opening of schools in Lilongwe and Blantyre due to an outbreak of cholera, which has killed 595 people so far, including 19 people on New Year's Eve. (BBC News)

Law and crime

- 2016 Indian banknote demonetisation
  - The Supreme Court of India upholds the legality of the government's decision to demonetise all ₹500 and ₹1,000 banknotes of the Mahatma Gandhi Series in 2016. (AP)

Politics and elections

- Qatar corruption scandal at the European Parliament
  - President of the European Parliament Roberta Metsola initiates a formal procedure to revoke parliamentary immunity from two MEPs allegedly involved in the scandal. (AFP via Bangkok Post)

Sports

- 2022 NFL season
  - Buffalo Bills safety Damar Hamlin suffers from a cardiac arrest during a Monday Night Football game against the Cincinnati Bengals and is taken to the University of Cincinnati Academic Health Center by ambulance. The NFL subsequently suspends the game and cancels it three days later. (CBS Sports)

January 3, 2023 (2023-01-03) (Tuesday)

Armed conflicts and attacks

- Russian invasion of Ukraine
  - Makiivka military quarters shelling
    - The Russian defense ministry increases the death toll of soldiers from a December 31 Ukrainian missile attack in Makiivka, Donetsk Oblast, to 89. The ministry attributes the casualties to the soldiers' use of mobile phones with tracking systems. (AFP via ABS-CBN News)
- Mexican drug war
  - Aftermath of the 2023 Ciudad Juárez prison attack
    - Five gunmen and two members of the security forces are killed during a shootout while searching for 30 inmates who escaped two days ago during an armed attack on a prison in Ciudad Juárez, Chihuahua, Mexico. Ten prison guards and seven inmates were killed during the attack. (BBC News)
- Yemeni Civil War
  - Five people are killed and many more wounded during a gunfight between Houthi militants and Yemeni soldiers in Taiz. (Xinhua)
- Israeli–Palestinian conflict
  - The visit of the Israeli Minister of National Security Itamar Ben-Gvir to the Temple Mount in Jerusalem results in protests by Palestinians as well as condemnation of the visit by several Arab countries, who consider the site to be part of the Al-Aqsa Mosque. (BBC News) (Al Jazeera)
- Jihadist insurgency in Burkina Faso
  - Twenty-eight civilians are found dead in the town of Nouna, in northwest Burkina Faso. Burkinabé human rights groups say that the killings were perpetrated by pro-government militia VDP on December 15, 18, and 22. (Atlas) (Reuters)

Business and economy

- 2021–2023 global energy crisis
  - 2022–2023 Pakistan economic crisis
    - The government orders the closure of all shopping malls and retail markets by 8:30 p.m. (PKT) daily as part of an energy conservation plan to offset increasing energy prices. (Reuters)

Politics and elections

- 2023 Speaker of the United States House of Representatives election
  - The 118th United States Congress begins, with the House Speaker election heading to multiple ballots for the first time in 100 years after Kevin McCarthy fails to receive the required number of votes on the first three ballots. (ABC News)

Sports

- 2022–23 snooker season
  - The World Professional Billiards and Snooker Association suspends Chinese players Zhang Jiankang and Zhao Xintong from the World Snooker Tour as part of a match-fixing investigation involving ten Chinese players. (AFP via France 24)
- 2023 PDC World Darts Championship
  - Michael Smith wins the PDC World Darts Championship after defeating Michael van Gerwen 7–4 in the final, winning his first world title and reaching world number one on the PDC Order of Merit for the first time. (Sky Sports)

January 4, 2023 (2023-01-04) (Wednesday)

Armed conflicts and attacks

- Somali Civil War
  - Mahas bombings
    - Al-Shabaab jihadists kill 35 people in a double car bombing outside a politician's home and a market in Mahas District, Hiran, Somalia. (BBC News)
- Terrorism in Pakistan
  - Two intelligence officers, including the director of the provincial counterterrorism department, are shot dead outside a restaurant in Khanewal, Punjab, Pakistan, by suspected Pakistani Taliban gunmen. (Al Jazeera)

Arts and culture

- #MeToo movement
  - Actors Leonard Whiting and Olivia Hussey, who starred in the 1968 film adaptation of William Shakespeare's Romeo and Juliet, file a lawsuit in the Los Angeles County Superior Court against Paramount Pictures for US$500 million, alleging sexual abuse, sexual harassment, and fraud, and for being filmed in the nude without their knowledge. (AFP) (Variety)

Business and economy

- Meta Platforms is fined €390 million by the European Union, claiming that the company's collection of personal data from Facebook and Instagram accounts for personalized ads was in violation of EU privacy laws. (Reuters)
- The Competition Commission of India rejects an appeal from Google over its ruling in October that Google's dominant position in the search engine market and control of the Android app store violated India's antitrust laws. (Reuters)

International relations

- Equatorial Guinea–Spain relations
  - The Supreme Court of Spain says that it will investigate two sons of Equatorial Guinean president Teodoro Obiang Nguema Mbasogo over the kidnapping and torture of two Spanish citizens who oppose Obiang's rule. (VOA)

Law and crime

- Killing of the Haynie family
  - Three adults and five children are found dead inside a home in Enoch, Utah, United States, after police conduct a welfare check. (The New York Times)

Science and technology

- Hurricane Katrina
  - The National Hurricane Center publishes a new Tropical Cyclone Report for Hurricane Katrina, lowering the death toll from over 1,800 to 1,392. (National Hurricane Center via Twitter)(National Hurricane Center)

January 5, 2023 (2023-01-05) (Thursday)

Armed conflicts and attacks

- Russo-Ukrainian War
  - 2022 Russian invasion of Ukraine
    - 2023 Russian Christmas truce proposal
      - Following the suggestion of Patriarch Kirill of Moscow, Russian President Vladimir Putin announces a unilateral ceasefire on January 6–7 in connection with Orthodox Christmas. However, Ukraine rejects an offer to respond with a mutual ceasefire, citing lack of trust. (Reuters)
    - Foreign aid to Ukraine during the Russo-Ukrainian War
      - The United States and Germany agree to send Bradley Fighting Vehicles and Marder infantry fighting vehicles to Ukraine. Germany will also supply the Ukrainian military with a MIM-104 Patriot surface-to-air missile system. (The Guardian) (AFP via The Times of Israel)
- Mexican drug war
  - 2023 Sinaloa unrest
    - The army arrests Ovidio Guzmán López, the son of incarcerated drug lord Joaquín "El Chapo" Guzmán, in Culiacán, Sinaloa. The arrest is followed by state-wide unrest, with many schools and airports closed. Ten soldiers and 19 gang members are killed during the unrest. (BBC News) (The Guardian)
- Afghanistan conflict
  - Islamic State–Taliban conflict
    - The Taliban says that its forces have killed eight Islamic State insurgents, including foreign nationals, and arrested seven others in a series of raids in Kabul and the western Nimruz Province, following recent attacks by the jihadist group. (Al Jazeera)
- Aegean dispute
  - A Turkish coast guard vessel exchanges warning shots with a Greek coast guard vessel near the Greek island of Farmakonisi. (AP)

Disasters and accidents

- Three people are killed and nine others are injured after a building collapses in Mosul, Iraq. (NewsToday)

Health and environment

- COVID-19 pandemic
  - COVID-19 pandemic in Greece
    - Travel during the COVID-19 pandemic
      - Greece announces that travelers from China will require a negative COVID-19 test in order to enter the country. (Reuters)

Politics and elections

- Death and funeral of Pope Benedict XVI
  - The funeral for Pope emeritus Benedict XVI takes place in St. Peter's Square, Vatican City, with at least 50,000 attendees. (AP)
- The government of Chad reports that an "attempted destabilization" plot led by military and human rights activists has failed. The statement says that the arrests of the 11 people involved took place later than 8 December 2022. (AFP via France 24)

January 6, 2023 (2023-01-06) (Friday)

Armed conflicts and attacks

- Russo-Ukrainian War
  - 2022 Russian invasion of Ukraine
    - Battle of Donbas, 2023 Russian Christmas truce proposal
      - Russian forces shell the front line city of Kramatorsk, damaging at least fourteen homes, according to the city's mayor, with no reports of casualties. Meanwhile, Donetsk People's Republic officials accuse Ukraine of shelling Donetsk with artillery. (Reuters via The Straits Times) (BBC News)
    - Southern Ukraine campaign
      - A Russian missile strike near a fire station in Kherson, kills one person and injures four others, according to regional official Yaroslav Yanushevych. (Ukrinform)
- Mexican drug war
  - 2023 Sinaloa unrest
    - Mexico's secretary of defense Luis Cresencio Sandoval reports that a total of 29 people, 19 gang members and ten military personnel, were killed during the operation which ended in the arrest of Ovidio Guzmán. (Reuters)
- Somali Civil War
  - At least 20 people are killed and many more injured during an ambush by Al-Shabaab insurgents at a government base at the Hilowle Gaab village. (Horn Observer)
  - Al-Shabaab gunmen storm a village in Hirshabelle State that was captured from the jihadist group last week, killing at least six people. (Al Jazeera)

Business and economy

- 2021–2023 inflation surge
  - 2022–2023 food crises
    - The United Nations' Food and Agriculture Organization reports that international food prices reached a record high in 2022 amid ongoing concerns of food shortages. (Reuters)

Disasters and accidents

- At least 16 people are killed and 21 others are injured when a bus crashes while travelling from Kampala to Gulu in northern Uganda. (Daily Monitor via The East African)
- One person is killed and two others are injured when a crane collapses in Melhus, Trøndelag, Norway. (DW)

International relations

- Afghanistan–China relations
  - The Taliban and the Xinjiang Central Asia Petroleum and Gas Company of China agree to a 25-year deal to allow the Chinese firm to drill for oil in the Amu Darya basin. It is Afghanistan's first major energy extraction agreement with a foreign firm since the Taliban returned to power in 2021. (BBC News)

Law and crime

- Censorship in Saudi Arabia, Censorship of Wikipedia
  - Saudi Arabia sentences two Wikipedia administrators to 32 and 8 years in prison, respectively, in relation to their activities on the website. (AFP via The Guardian)
- Toxic cough syrup
  - State security police in Uzbekistan arrest four people over the deaths of 19 children who consumed a cough syrup product manufactured by Indian drug manufacturer Marion Biotech last week. (RFE/RL)
- Mali War
  - Interim president Assimi Goïta pardons 49 Ivorian soldiers who were arrested in July and convicted of "undermining state security". (AFP via VOA)
- Incarceration of Ana Montes
  - After serving 20 years in prison, Ana Montes, a former senior analyst at the Defense Intelligence Agency in the United States, who spied on behalf of the Cuban government for 17 years, is released from the FMC Carswell in Fort Worth, Texas. (CNN)

January 7, 2023 (2023-01-07) (Saturday)

Armed conflicts and attacks

- Boko Haram insurgency
  - Thirty-five Islamic State members are killed during a fight with Boko Haram militants in Lake Chad, resulting in the dislodgement of Islamic State from two of its enclaves. (Punch)

Disasters and accidents

- Five people are killed and 23 others are injured in a bus crash in Diyarbakır, Turkey. (Armenpress)
- Five people are killed and ten others are missing after a boat carrying migrants sinks off the coast of Tunisia. (Al Jazeera)
- 2023 Mexico City Metro train crash
  - One person is killed and 57 others are injured when two trains crash on Line 3 of the Mexico City Metro in Mexico City. (The Guardian) (Excélsior in Spanish)
- Two people are killed and another person is injured when a roof collapses in Alexandria, Egypt. (The Washington Post)
- Twenty-one people are killed and 49 others are injured when a bus heading for Nairobi, Kenya, crashes after crossing the border from Uganda. (AFP via Barron's)

Law and crime

- One person is killed and 60 others are injured in a prison riot in Pathein, Myanmar. (AFP via Hindustan Times)
- South Sudanese authorities arrest six journalists from the country's public broadcaster on suspicion of distributing unauthorized footage of President Salva Kiir Mayardit that went viral internationally in December. (AP via ABC News Australia)

Politics and elections

- 2023 Speaker of the United States House of Representatives election
  - Kevin McCarthy is elected speaker of the United States House of Representatives after fifteen rounds of voting, the most rounds since 1860. (BBC News)

January 8, 2023 (2023-01-08) (Sunday)

Armed conflicts and attacks

- 2022–2023 North Kosovo crisis
  - NATO rejects Serbia's request to deploy up to 1,000 Serbian troops and military police in North Kosovo. (Reuters)
- 2023 Brazilian Congress attack
  - Pro-Bolsonaro protesters storm the National Congress, the Supreme Federal Court, and the Palácio do Planalto in Brasília, Brazil. (France 24)

Disasters and accidents

- Kaffrine bus crash
  - At least 40 people are killed and 87 others are injured when two buses collide in Gniby, Kaffrine Department, Senegal. (Al Jazeera)
- A truck crashes into a funeral procession in Nanchang County, Jiangxi, China, killing 19 people and injuring 20 others. (AFP via South China Morning Post)

Law and crime

- Islamic terrorism in Europe, Terrorism in Germany
  - North Rhine-Westphalia Police arrest two Iranian brothers in Castrop-Rauxel, Ruhr, Germany, on suspicion of planning an Islamic terrorist attack using chemical weapons. (BBC News)

Politics and elections

- 2023 Beninese parliamentary election
  - Citizens in Benin head to the polls to elect the 109 members of the National Assembly. (Al Jazeera)

Sports

- 2023 ATP Tour, 2023 WTA Tour
  - 2023 United Cup
    - The United States tennis team wins the inaugural edition of the United Cup after defeating Italy 4–0 in the final at the Ken Rosewall Arena in Sydney. (AP via The Indian Express)
- 2022–23 FIS Alpine Ski World Cup
  - American alpine skier Mikaela Shiffrin equals fellow American Lindsey Vonn's record of 82 wins, the most by a woman in the FIS Alpine Ski World Cup, after winning the giant slalom at Kranjska Gora, Slovenia. (CNN)

January 9, 2023 (2023-01-09) (Monday)

Armed conflicts and attacks

- 2022–2023 Peruvian political protests
  - Juliaca massacre
    - At least 18 people are killed and over 100 others are injured when the Peruvian National Police fire upon demonstrations in Juliaca. (Reuters)

Disasters and accidents

- 2023 Maluku earthquake
  - One person is killed and eight others are injured after a magnitude 7.6–7.9 earthquake hits off the coast of eastern Indonesia, causing damage to buildings, and shaking buildings as far away as Darwin, Australia. (Maluku Terkini)
- Two people are killed in a plane crash near the town of Karataika, Nenets Autonomous Okrug, in Russia's far north. A total of twelve people were on board the plane. (RFE/RL)

Health and environment

- COVID-19 pandemic
  - COVID-19 pandemic in China
    - Travel during the COVID-19 pandemic
      - China reopens its borders for unrestricted travel, marking the repeal of the country's last Zero-COVID policy. (Bloomberg)

Law and crime

- 2023 Brazilian Congress attack
  - Around 1,200 supporters of former Brazilian President Jair Bolsonaro are arrested following yesterday's riots in Brasília. (The New York Times)
- Armenia–Russia relations, 2022–2023 blockade of the Republic of Artsakh
  - Protests break out in the city of Gyumri in Armenia against the Russian military presence in the country and the Russian peacekeepers' inaction in ending the Lachin corridor blockade. Dozens of protesters are arrested by police after they attempted to reach the Russian military base near the city to blockade it. (OC Media)

Politics and elections

- Gabonese President Ali Bongo Ondimba names Alain Claude Bilie By Nze as the new prime minister and head of government, replacing Rose Christiane Raponda. (Xinhua)

Science and technology

- British space programme
  - Virgin Orbit's LauncherOne fails to reach the Low Earth orbit with a payload of several small satellites after the rocket suffered a second-stage engine anomaly on its ascent to space, resulting in the loss of the payload. The mission, which launched from Spaceport Cornwall in South West England, would have been the first rocket launched from United Kingdom territory. (AFP via Hindustan Times)
- An X1.9-class solar flare erupts from an active sunspot while facing Earth causing temporary radio blackouts in parts of South America, according to the National Oceanic and Atmospheric Administration. The source is "hyperactive sunspot AR3184", which also caused a X1.2-class solar flare on January 5. (Space.com)

Sports

- 2023 College Football Playoff National Championship
  - In American football, the Georgia Bulldogs repeat as national champions, defeating the TCU Horned Frogs in a 65–7 blowout. (NPR)
- Aftermath of the 2021 NWSL abuse scandal
  - The National Women's Soccer League of the United States bans former coaches Richie Burke of Washington Spirit, Rory Dames of Chicago Red Stars, Christy Holly of Racing Louisville, and Paul Riley of North Carolina Courage for life following an investigation on allegations of abuse throughout the 2021 season. (The Washington Post)

January 10, 2023 (2023-01-10) (Tuesday)

Armed conflicts and attacks

- Russo-Ukrainian War
  - 2022 Russian invasion of Ukraine
    - Battle of Soledar
      - The UK Defence Ministry says that Russian forces are in control of most of Soledar in Donetsk Oblast. Wagner Group leader Yevgeny Prigozhin, however, claims the city had been taken in its entirety. (The Guardian)

International relations

- China–Japan relations, China–South Korea relations
  - Travel during the COVID-19 pandemic
    - China suspends the issuance of short-term travel visas to Japanese and South Korean citizens in order to reciprocate the two countries' imposition of travel restrictions on Chinese citizens in response to China's recent COVID-19 surge. (AFP via Channels TV) (AFP via The Manila Times)
- Nagorno-Karabakh conflict
  - Armenia–Russia relations
    - Armenian prime minister Nikol Pashinyan announces the postponement of joint military exercises with the Russian Armed Forces under the Collective Security Treaty Organization this year, citing the organization's refusal to condemn Azerbaijan over the disputes. (AFP via Al Arabiya)

Law and crime

- 2022–2023 Peruvian political protests
  - Aftermath of the Juliaca massacre
    - Prime Minister Alberto Otárola imposes a three-day curfew in the Puno region from 8 pm to 4 am (PET) the following day in an effort to repress the protests. (AFP via France 24)
- Government and intergovernmental reactions to the 2022 Russian invasion of Ukraine
  - Ukrainian president Volodymyr Zelenskyy denaturalizes pro-Kremlin politician Viktor Medvedchuk and three others for high treason. (AFP via Hindustan Times)
- New York investigations of The Trump Organization
  - The New York City Criminal Court sentences former Trump Organization chief financial officer Allen Weisselberg to five months in the infirmary unit of Rikers Island for tax fraud and tax evasion. (AFP via NDTV)
- Territorial disputes in the South China Sea
  - The Supreme Court of the Philippines nullifies the country's Joint Marine Seismic Undertaking agreement with the China National Offshore Oil Corporation and Petrovietnam to conduct joint oil and gas exploration activities within the Philippine exclusive economic zone in the South China Sea since 2005, citing the unconstitutionality of permitting foreign corporations and governments to exploit the country's natural resources. (Reuters via CNN)
- Corruption in Indonesia
  - The Corruption Eradication Commission arrests Governor of Papua Lukas Enembe as part of an investigation into corruption in the region's infrastructure development. (Detik)
- A Revolutionary Court in Tehran, Iran, sentences Olivier Vandecasteele, a Belgian aid worker to a minimum of 12 and a half years in prison and 74 lashes on espionage charges. (AP via VOA)

Science and technology

- Microsoft ends support for Windows 8.1 and security updates for Windows 7. (Tech Crunch)

January 11, 2023 (2023-01-11) (Wednesday)

Armed conflicts and attacks

- Russo-Ukrainian War
  - 2022 Russian invasion of Ukraine
    - Order of battle for the 2022 Russian invasion of Ukraine
      - Chief of the General Staff of the Russian Armed Forces Valery Gerasimov is appointed commander of the Joint Group of Forces participating in the war with Ukraine. Generals Oleg Salyukov, Alexei Kim, and Sergei Surovikin, who previously held this position, become his deputies. (Fontanka.ru)
- Afghanistan conflict
  - Islamic State–Taliban conflict
    - Ministry of Foreign Affairs of Afghanistan bombing
      - An Islamic State suicide bomber blows himself up at the entrance of the foreign ministry offices in Kabul, Afghanistan, killing at least 20 people and many others injured. (Al Jazeera)

Health and environment

- 2022 Uganda Ebola outbreak
  - Ugandan Health Minister Jane Aceng declares an end to the outbreak of Sudan ebolavirus in the country that has killed 77 people since September. (Reuters)

International relations

- Japan–United States relations
  - United States Secretary of State Antony Blinken announces that Japan and the United States will include space warfare as a trigger for the Treaty of Mutual Cooperation and Security. (AFP via GMA News Online)

Law and crime

- Five people are killed and 13 others injured when a man rams his vehicle into a crowd in Guangzhou, China. (BBC News)
- Six people are injured in a mass stabbing at the Gare du Nord train station in Paris, France. The attacker is shot by police, arrested, and hospitalized. (BBC News)
- Joe Biden classified documents incident
  - Aides to the President of the United States Joe Biden discover a second set of classified documents besides those found on Monday in a Washington, D.C. office. The White House acknowledges the discovery. (NBC News)

Science and technology

- 2023 FAA system outage
  - For the first time since 9/11, the FAA issues a nationwide ground stop in the United States following the failure of the FAA's NOTAM system. (CNBC)
- The launch of an unmanned ABL Space Systems RS1 rocket fails at the Pacific Spaceport Complex – Alaska in Kodiak, Alaska, United States. The rocket crashes during the launch, damaging the launch platform and destroying the rocket and its cargo. (Anchorage Daily News)
- The United Kingdom's postal service Royal Mail tells people to stop sending mail abroad due to a "cyber incident" that is causing severe disruption to mail delivery, with "minor delays" to mail coming into the UK also being reported. It is later confirmed to be a ransomware attack from a Russia-linked hacker group. (BBC News)

January 12, 2023 (2023-01-12) (Thursday)

Armed conflicts and attacks

- Israeli–Palestinian conflict
  - Israeli soldiers raid the village of Qabatiya in the West Bank, killing two Palestinian men. In a separate incident, Israeli forces arrest an 18-year-old Palestinian man and kill his father in the Qalandia refugee camp. (AP via The Washington Post) (Ynetnews)
- 2022–2023 Peruvian political protests
  - The city of Cusco is placed under red alert after one person is killed and 17 others are injured in clashes between protesters and police. (CNN)

Business and economy

- 2021–2023 inflation surge
  - The National Institute of Statistics and Census of Argentina records a 94.8% inflation rate for its economy in 2022, the highest since 1991. (AFP via Buenos Aires Times)

Disasters and accidents

- Tornado outbreak of January 12, 2023
  - A tornado outbreak in the US states of Alabama and Georgia damages several towns and kills at least six people. (USA Today)
- A truck crashes into several minibus taxis at an intersection in Roodepoort, Gauteng, South Africa, killing five people and injuring nine others. (News24)
- An explosion at a propane store in Saint-Roch-de-l’Achigan, Quebec, Canada leaves three people missing. (CFCF-DT)

Health and environment

- Swedish mining company LKAB discovers Europe's largest known deposit of rare-earth elements in Kiruna, Sweden. (Reuters)
- The World Meteorological Organization of the United Nations reports an average global temperature of about 1.15 °C above pre-industrial levels in 2022, confirming that the last eight years were the highest temperatures recorded on Earth since records began. (AFP via The Philippine Star)

Politics and elections

- 2023 Beninese parliamentary election
  - The Constitutional Court declares that the parties supporting President Patrice Talon, including the Progressive Union for Renewal and the Republican Bloc, have won a majority of 81 out of 109 seats in the National Assembly. The parties have been accused of electoral fraud by the opposition Democrats party, who plan to contest the results. (AFP via RFI)

Sports

- International response to the treatment of women by the Taliban
  - Cricket Australia announces the withdrawal of the Australia national team from their One Day International matches against Afghanistan scheduled for March in response to the Taliban government's recent prohibitions of education and employment for women. (CNN)

January 13, 2023 (2023-01-13) (Friday)

Armed conflicts and attacks

- Russo-Ukrainian War
  - 2022 Russian invasion of Ukraine
    - Battle of Soledar
      - Russia's defence ministry says that its forces have taken full control of Soledar in Donetsk Oblast. However, Ukraine denies the fall of the city and its salt mines, claiming that the battle was still ongoing. (BBC News)

Disasters and accidents

- 2023 Lithuania–Latvia pipeline explosion
  - A large explosion occurs on the Lithuania–Latvia Interconnection natural gas pipeline in Pasvalys District Municipality, Lithuania. Latvian Defence Minster Artis Pabriks says that the cause of the explosion would be investigated and that sabotage "could not be ruled out". (BBC News) (Reuters)

Law and crime

- Aftermath of the assassination of Shinzo Abe
  - Prosecutors in Japan charge the 42-year-old accused killer of former prime minister Shinzo Abe with murder. Additional charges are expected after the man was found competent by psychiatrists earlier this week. (The Asahi Shimbun) (Reuters)
- New York investigations of The Trump Organization
  - The New York County Courthouse issues the maximum allowable $1.6 million fine on the Trump Organization, former president Donald Trump's conglomerate, for tax fraud, conspiracy, and falsifying business records. (AFP via France 24)
- The British government announces a ban on single-use plastic cutlery, plates, polystyrene cups, bowls, and balloon sticks in England beginning in October as part of an effort to reduce plastic pollution. The ban will apply to all retailers, takeaways, and food vendors. (BBC News)

Politics and elections

- 2023 Czech presidential election
  - Czechs head to the polls to elect their president. Incumbent Miloš Zeman is not eligible to run for re-election, as he is term limited. (Euronews)

January 14, 2023 (2023-01-14) (Saturday)

Armed conflicts and attacks

- 2022 Russian invasion of Ukraine
  - 2022–2023 Russian strikes against Ukrainian infrastructure
    - 2023 Dnipro residential building airstrike
      - Russia strikes a nine-story residential building in Dnipro with a cruise missile, killing at least 40 people, injuring 73 others and leaving dozens more missing. (Reuters) (Al Jazeera)
  - Foreign aid to Ukraine during the Russo-Ukrainian War
    - UK Prime Minister Rishi Sunak confirms that the United Kingdom will send 14 Challenger 2 main battle tanks to Ukraine in the coming weeks, as well as 30 self-propelled AS-90 howitzers. Ukrainian troops will also be trained by the British Armed Forces to operate the tanks. (Reuters)
- Somali Civil War
  - Eleven people are killed and more than 50 injured by an al-Shabaab suicide car bombing in Buloburde, Hiran. (VOA)
- Israeli–Palestinian conflict
  - Two Palestinian Islamic Jihad members are killed by Israeli soldiers during a raid in Jaba, in the West Bank. (Al Jazeera)

Arts and culture

- Miss Universe 2022
  - Miss America R'Bonney Gabriel is crowned Miss Universe by her predecessor, Harnaaz Sandhu. (CNN)

Law and crime

- Capital punishment in Iran
  - Iran announces the execution of dual British Iranian citizen Alireza Akbari, who had served as a deputy for the ministry of defense, on charges of spying for the United Kingdom. British Prime Minister Rishi Sunak condemns Akbari's execution. (Reuters)
- 2022–2023 Peruvian political protests
  - The government declares a 30-day state of emergency in Lima and three other regions in response to the violent protests. (AFP via Gulf News)
- Euston shooting
  - Six people are injured by a mass drive-by shooting in London, United Kingdom. (BBC News)

Politics and elections

- 2023 Czech presidential election
  - Retired general Petr Pavel and former Prime Minister Andrej Babiš advance to a runoff vote in the Czech presidential election, which will be held on January 27–28. (DW)

January 15, 2023 (2023-01-15) (Sunday)

Armed conflicts and attacks

- Kivu conflict
  - Allied Democratic Forces insurgency
    - Kasindi church bombing
      - Ten people are killed and 39 others are injured when a bomb explodes at a Pentecostal church in Kasindi, North Kivu, Democratic Republic of the Congo. The Islamic State has claimed responsibility for the attack. (Al Jazeera)
- Afghanistan conflict
  - Former lawmaker Mursal Nabizada and one of her bodyguards are shot and killed in Kabul inside her home, while her brother and a second security guard are injured. Taliban police spokesman Khalid Zadran condemns the killing and says that a "serious investigation has been launched". (AFP via Arab News)
- Jihadist insurgency in Burkina Faso
  - Jihadists kidnap dozens of women in Arbinda, Sahel Region, Burkina Faso, according to local officials. (BBC News)

Disasters and accidents

- Yeti Airlines Flight 691
  - A plane which had departed from Kathmandu crashes in Pokhara, Gandaki Province, Nepal, killing all 72 people on board. (BBC News) (Reuters)
- 2022–2023 California floods
  - President of the United States Joe Biden issues a major disaster declaration for the state of California following major flooding. (The Guardian)
- A light aircraft crashes in Nasrec, Johannesburg, South Africa, killing all three people on board. (UrduPoint)

Law and crime

- Two suspected drug traffickers are killed in a shootout with United States Customs and Border Protection officials off the coast of Puerto Rico. (AP)
- The Jamaica Constabulary Force seizes $80 million worth of cocaine from a cargo ship at the port of Kingston. (Reuters)

January 16, 2023 (2023-01-16) (Monday)

Armed conflicts and attacks

- 2022 Russian invasion of Ukraine
  - Battle of Soledar
    - Ukraine announces defeat at Soledar after days of intense fighting. (MSN)
- Tigray War
  - Tigrayan peace process
    - Amharan Special Forces announce their withdrawal from the Tigray Region in line with an African Union-backed peace agreement between the Ethiopian government and the Tigray People's Liberation Front. (Al Jazeera)
- Somali Civil War
  - The Somali Armed Forces claim to have recaptured the port town of Harardhere from Al-Shabaab militants. According to a Puntland officer, Somali forces allied with regional militias also recaptured the town of El Dhere. (Al Jazeera) (The Globe and Mail)

Disasters and accidents

- International Kite Festival in Gujarat – Uttarayan
  - At least six people including three children died and 176 people were injured from cuts and falls while flying kites during Uttarayan festival in Gujarat. Some bled to death as revellers used sharp strings that entangled around the necks. (The Tribune)
- Nineteen people are killed and 24 others are injured during a collision between a bus and a truck in Sakal Arrondissement, Senegal. (Al Jazeera)

Law and crime

- Goshen shooting
  - Six people, including a baby, are killed in a mass shooting in Goshen, California, United States. The shooting is believed to have been perpetrated by cartel members. (CNN)
- Metropolitan Police Parliamentary and Diplomatic Protection officer David Carrick pleads guilty to 49 offences, including 24 rapes, at Southwark Crown Court in London, UK. (BBC News)
- Mafia boss Matteo Messina Denaro, one of the most wanted men in Italy and Europe, is arrested in Palermo, Sicily, Italy, after 30 years on the run. (BBC News)
- Solomon Peña, a former Republican candidate for the New Mexico House of Representatives, is arrested by SWAT officers for his role in the shootings of at least four New Mexico Democrat politicians' houses. (AP News)

Politics and elections

- LGBT rights in Scotland
  - The British government says that it will block the Gender Recognition Reform Bill passed by the Scottish Parliament despite objections from First Minister Nicola Sturgeon, saying that the proposed law would conflict with "equality protections" across Great Britain. (BBC News)
- German Defence Minister Christine Lambrecht resigns from the Scholz cabinet amid criticism of her response to the war in Ukraine. (Reuters)

January 17, 2023 (2023-01-17) (Tuesday)

Armed conflicts and attacks

- Somali Civil War
  - Seven soldiers, including a commander, are killed when al-Shabaab jihadists attack a military base in Hawadley, Middle Shabelle, with a suicide car bomb and gunmen. (Reuters)

Business and economy

- Travel during the COVID-19 pandemic, Economic impact of the COVID-19 pandemic
  - The World Tourism Organization reports that the figures for international tourist arrivals worldwide had doubled in 2022 compared to the previous year, citing the easing of COVID-19 pandemic-related travel restrictions. (AFP via RFI)

Disasters and accidents

- Bear attacks
  - A polar bear attacks and kills a woman and her son in Wales, Alaska, United States, after charging several others, in the first fatal attack since the early 1980s. The bear is shot and killed following the attack. (CNN) (BBC News)

Health and environment

- Aging of China
  - The National Bureau of Statistics reports that China's population, the largest in the world, declined for the first time since 1960, with a population decrease of 850,000 people reported in the past year. (AFP via France 24) (The New York Times)
- French Catholic nun Lucile Randon, who had been the world's oldest verified living person since April 2022 and the fourth verified oldest woman, dies at the age of 118. (AFP via Manila Bulletin)

International relations

- International response to the 2022 Russian invasion of Ukraine
  - United States and the 2022 Russian invasion of Ukraine
    - Ukraine–United States relations
      - Commander-in-Chief of the Armed Forces of Ukraine Valerii Zaluzhnyi and Chairman of the Joint Chiefs of Staff of the United States Mark Milley meet for the first time in person. (AFP)

Politics and elections

- Nguyễn Xuân Phúc resigns as president of Vietnam, the second highest-ranked position in the country, citing responsibility for several recent scandals in the government. (VnExpress)

January 18, 2023 (2023-01-18) (Wednesday)

Armed conflicts and attacks

- 2022 Russian invasion of Ukraine
  - During a visit to Kyiv, Canadian National Defence Minister Anita Anand announces that Canada will send 200 Roshel Senator armoured personnel carriers to Ukraine. (CBC News)
- Spillover of the Somali Civil War
  - Ten Al-Shabaab militants are killed during a raid by security forces in the village of Galmagala, Garissa County, Kenya, after the group killed five civilians in the region last week. Rocket-propelled grenades and improvised explosive devices are recovered. (Al Jazeera)
- Ituri conflict
  - The United Nations reports the discovery of mass graves in Ituri Province, Democratic Republic of the Congo, containing the bodies of 49 civilians. CODECO militants are suspected of being behind the killings. (AP)

Business and economy

- 2021–2023 inflation surge
  - 2021–present United Kingdom cost of living crisis
    - Despite a slight decrease in overall inflation at the end of last year, food prices in the United Kingdom increased by 16.9% in the twelve months to December, the highest rate since September 1977, according to the Office for National Statistics. (Evening Standard)
  - Microsoft announces that it will cut 10,000 jobs, around 5% of its global workforce, amid a slowdown in consumer spending. (BBC News)

Disasters and accidents

- 2023 Brovary helicopter crash
  - Fourteen people are killed and 25 others are injured in a helicopter crash in Brovary, Kyiv Oblast, Ukraine. Interior minister Denys Monastyrsky, deputy minister of internal affairs Yevhen Yenin, and state secretary of internal affairs Yurii Lubkovych are among those killed. (Al Jazeera)
- List of earthquakes in 2023
  - At least 150 people are injured by a magnitude 5.8 earthquake in Khoy, Khoy County, West Azerbaijan, Iran. (MehrNews)
- At least 70 people and 70,000 cattle are killed due to freezing temperatures across Afghanistan. (Al Jazeera)

Law and crime

- Stop Cop City
  - A protester is killed and a Georgia State Patrol trooper is injured after they exchange fire during a clearing operation against demonstrators attempting to prevent the construction of a police training facility at a forest in Atlanta, Georgia, United States. (Atlanta Journal-Constitution)
- The Court of Tax Appeals of the Philippines acquits journalist Maria Ressa and her online news website Rappler of charges of tax evasion filed against them by the government in 2018. (AFP via RFI)

Politics and elections

- 2023 Antiguan general election
  - Citizens in Antigua and Barbuda head to the polls to elect members of the House of Representatives. (Jamaica Gleaner)
- 2023 Brazilian Congress attack
  - President Luiz Inácio Lula da Silva dismisses 13 more military personnel from the presidential cabinet whom he blames for the January 8 attack in Brasília. (Reuters)

January 19, 2023 (2023-01-19) (Thursday)

Armed conflicts and attacks

- Russo-Ukrainian War
  - 2022 Russian invasion of Ukraine
    - Swedish Defence Minister Pål Jonson announces that Sweden will send its self-propelled Archer Artillery System, 50 Combat Vehicle 90 IFVs, and NLAW anti-tank missiles to Ukraine as part of its latest military support package for the Ukrainian military. (Politico)
- Jihadist insurgency in Burkina Faso
  - Sixteen VDP members and 14 civilians are killed during four attacks by Islamic extremists in Burkina Faso. At least ten attackers are also killed. (VOA)
- Israeli–Palestinian conflict
  - A Palestinian teacher and a member of the Jenin Brigades are killed, and three others are injured, in a raid by Israeli soldiers at a refugee camp in Jenin, in the West Bank. (Al Jazeera) (BBC News)
- Insurgency in Khyber Pakhtunkhwa
  - Three police officers are killed in a suicide bombing at a police outpost in Khyber Pakhtunkhwa, Pakistan. (Reuters)
- Five Iraqis from Duhok, Kurdistan Region, Iraq, are shot and killed by gunmen on a road in Mardin Province, Turkey. Two of the victims were prominent imams in Duhok. (The National News)

Business and economy

- 2023 United States debt-ceiling crisis
  - The United States reaches its debt ceiling of $31.4 trillion, requiring the Treasury Department to suspend the issuance of new Treasury securities and take extraordinary measures to prevent a default. (CNN)
- Retail apocalypse
  - British catalog retailer Argos says that it will close all of its stores in the Republic of Ireland by June, with the loss of 580 jobs, saying that the investment needed to modernize its operations in the country was "not viable". (BBC News)
- Netflix co-founder Reed Hastings steps down as co-CEO, having served in the position since its founding in 1997. Greg Peters is selected to succeed him. (BBC News)

Disasters and accidents

- Arabian Gulf Cup stampede
  - Four people are killed and around 80 others are injured during a stampede at a stadium in Basra, Iraq. It is suspected that the incident occurred when some people tried to push their way into the stadium. (Al Jazeera)
- Fifteen servicemen are killed and seven others are injured in a fire at a barracks in Azat, Armenia. (AP)

International relations

- Iran–South Korea relations
  - Iran and South Korea summon each other's ambassadors in a deepening dispute between the countries, after South Korean President Yoon Suk-yeol called Iran "the enemy of the United Arab Emirates" while addressing South Korean troops stationed there. (Reuters)

Law and crime

- 2022–2023 Peruvian political protests
  - Thousands of protesters march in Lima demanding the resignation of president Dina Boluarte as the number of deaths from clashes between demonstrators and police exceeds 50. (Reuters)
- A judge in Bolivia rules that opposition figure Luis Fernando Camacho must remain in prison ahead of his trial. Camacho was arrested in December on charges of terrorism. (Reuters)
- Sierra Leonean president Julius Maada Bio signs into law a gender equality bill mandating the employment of at least 30 percent of women across all businesses. The law also guarantees at least 14 weeks of maternity leave and equal pay. (AFP via ABS-CBN News)

Politics and elections

- Protests against Emmanuel Macron
  - 2023 French pension reform strikes
    - A day of strikes and demonstrations occurs throughout France against the government's pension reform project, which proposes to raise the retirement age to 64. (Le Point)
- 2023 Kazakh legislative election
  - President Kassym-Jomart Tokayev dissolves the Mäjilis, ending the seventh convocation, and calls for a snap election on March 19. (AFP via The Hindu)
- Resignation of Jacinda Ardern
  - Jacinda Ardern announces her intention to resign as prime minister of New Zealand no later than February 7. (The Guardian)

January 20, 2023 (2023-01-20) (Friday)

Armed conflicts and attacks

- Russo-Ukrainian War
  - 2022 Russian invasion of Ukraine
    - Battle of Bakhmut
      - Russia claims that it captured the village of Klishchiivka in Donetsk Oblast, south of Bakhmut, and the village of Lobkove in Zaporizhzhia Oblast. (Al Jazeera)
- Insurgency in Balochistan
  - A bomb blast derails a passenger train in Peshi village, Kachhi District, Balochistan, Pakistan, injuring 13 people. (Al Jazeera)
- Jihadist insurgency in Burkina Faso
  - The Burkina Faso Armed Forces rescue 62 women and four babies kidnapped by jihadists in Arbinda, Sahel Region, on January 15. (AFP via Voice of America)
- The United States Department of the Treasury designates the Russian paramilitary organization Wagner Group as a transnational criminal organization, allowing provisions for international sanctions. (AFP via Le Monde)

Business and economy

- 2021–2023 inflation surge
  - The Bank of Japan reports that inflation in Japan increased by 4.0% in December, the highest recorded increase since 1981. (CNN) (BBC News)

Disasters and accidents

- 2023 Nyingchi avalanche
  - Twenty-eight people are killed and 53 others are rescued during an avalanche at a tunnel in Nyingchi, Tibet, China. (Al Jazeera)
- A Dominican man who was lost in the Caribbean Sea for 24 days is rescued by the Colombian Navy. (AP)
- Seven people are killed and over 50 are injured in a collision between a bus carrying students and a van in Radella, near Nuwara Eliya, Sri Lanka. (Gulf Today)

Health and environment

- COVID-19 pandemic
  - COVID-19 pandemic in South Korea
    - Prime Minister Han Duck-soo announces the termination of the country's indoor mask mandate, with the exception of public transport and medical facilities, effective January 30. (AFP via ABS-CBN News)

Law and crime

- Sagarejo shooting
  - A man opens fire from a balcony in Sagarejo, Kakheti, Georgia, killing five people and injuring five others. The gunman later commits suicide. (Global News)
- Rishi Sunak seatbelt incident
  - UK Prime Minister Rishi Sunak is fined £100 by Lancashire Constabulary for failing to wear a seat belt while recording a video for social media in the back of a moving car. (BBC News)

Sports

- 2022–23 Serie A
  - The Italian Football Federation sanctions Juventus F.C. with a 15-point deduction in the league table for capital gain violations. (AA)
- Rugby Australia suspends Waratahs full-back Kurtley Beale from all rugby union games following his arrest on sexual assault charges. (CNN)

January 21, 2023 (2023-01-21) (Saturday)

Armed conflicts and attacks

- Russo-Ukrainian War
  - 2022 Russian invasion of Ukraine
    - The Russian military says that it has launched offensive operations in Zaporizhzhia Oblast and "taken more advantageous lines and positions". (France 24)
- Tigray War
  - Tigrayan peace process
    - Eritrean forces withdraw from Shire and other major towns in the Tigray Region of Ethiopia. (Reuters)
- 2022–2023 Peruvian political protests
  - Peru indefinitely closes its iconic Machu Picchu historic site due to the ongoing unrest which has killed dozens of people. Around 500 foreign nationals are currently stranded in Peru. (BBC News) (AFP via France 24)
- Islamist insurgency in the Sahel
  - Burkina Faso demands that French forces withdraw from its territory after suspending a 2018 military accord that allowed the presence of French troops in the country. The ruling military junta has given France one month to complete the withdrawal. (Reuters)
- Yemeni Civil War
  - Six people are injured after a bomb explodes in al-Majaza, Shabwah Governorate, Yemen. (Middle East Monitor)

Arts and culture

- Japan wins the 2023 World Pastry Cup in Chassieu, Lyon Metropolis, France. (AFP via The Philippine Star)

Business and economy

- International sanctions during the 2022 Russian invasion of Ukraine
  - RT France, the French arm of the Russian state media network RT, ceases operation following the freezing of their bank accounts by the Direction générale du Trésor. (AFP via News18)

International relations

- Sweden–Turkey relations
  - The Turkish defense ministry cancels Swedish defense minister Pål Jonson's upcoming visit to Turkey in response to an approval for far-right extremist Rasmus Paludan to protest in front of the Turkish embassy in Stockholm. (AFP via The Jordan Times)

Law and crime

- 2023 Monterey Park shooting
  - Ten people are killed and ten others are injured in a mass shooting at a dance studio after Lunar New Year celebrations in Monterey Park, California, United States. The suspect, 72-year-old Huu Can Tran, escapes and later commits suicide. (Los Angeles Times)

Politics and elections

- 2023 Slovak constitutional referendum
  - Slovakians head to the polls to vote in a referendum to determine whether early elections can be called before the customary end of the mandate. (AP)
- 2023 Brazilian Congress attack
  - Commander of the Brazilian Army Júlio César de Arruda is fired by President Luiz Inácio Lula da Silva in the aftermath of the January 8 Congress attack and is replaced by Tomás Miguel Ribeiro Paiva. (AP)
- Tanzanian opposition party Chadema organizes a political demonstration in Mwanza. This is the country's first demonstration since President Samia Suluhu Hassan abolished her predecessor John Magufuli's seven-year ban on political assembly earlier this month. (AFP via VOA)

January 22, 2023 (2023-01-22) (Sunday)

Armed conflicts and attacks

- 2022 Russian invasion of Ukraine
  - Germany–Russia relations, Germany–Poland relations
    - German Foreign Affairs Minister Annalena Baerbock says that Germany will not prevent Poland from sending Leopard 2 main battle tanks to Ukraine which Ukrainian officials say are pivotal to defeating Russian forces. (Reuters)
- Arab–Israeli conflict
  - The Lebanese Army declares a "state of alert" after stopping Israeli bulldozers and accompanying soldiers from approaching a border fence in Southern Lebanon. Peacekeeping forces from UNIFIL have also been deployed to the area. (AA)

Disasters and accidents

- Four people are killed and three others are feared dead in an apartment fire in Kobe, Japan. (The Japan Times)
- At least 13 people are killed when a five-story building collapses in Aleppo, Syria, due to a leaking of water in the building's foundation. (Reuters)
- Four people are killed and six others are injured in a fire at a two-story cottage in Qusar, Azerbaijan. (Xinhua)

Law and crime

- Police in Cameroon find the mutilated body of prominent journalist Martinez Zogo, who had been kidnapped by unknown assailants five days ago, amid increasing violence against reporters in the country. (Reuters)

Politics and elections

- 2023 New Zealand Labour Party leadership election
  - The ruling Labour Party unanimously elects education and public service minister Chris Hipkins to succeed Jacinda Ardern as the party's leader following Ardern's resignation three days ago. Governor-General Cindy Kiro is expected to appoint Hipkins as the 41st prime minister of New Zealand on January 25. (AP)
- Israeli prime minister Benjamin Netanyahu dismisses health and interior minister Aryeh Deri from his cabinet after the Supreme Court ruled that Deri was barred from holding a position as a cabinet minister due to his conviction for tax offenses. (AFP via France 24)

Sports

- In surfing, American lifeguard Luke Shepardson wins the 2023 edition of The Eddie at Waimea Bay on the north shore of Oahu, Hawaii, United States, after finishing with 89.1 points out of 90, defeating defending champion John John Florence. (AP)

January 23, 2023 (2023-01-23) (Monday)

Armed conflicts and attacks

- Allied Democratic Forces insurgency
  - Makugwe massacre
    - Allied Democratic Forces insurgents kill 23 people at a bar in North Kivu, Democratic Republic of the Congo. The jihadists also torched several homes and shops in the village during the attack. Islamic State claims responsibility. (AFP via France 24)

Business and economy

- 2021–2023 inflation surge
  - Swedish music streaming service Spotify announces that it will cut 600 jobs, around 6% of its workforce, citing low revenue growth and a need to improve efficiency. Dawn Ostroff will also depart as its chief content and advertising business officer. (BBC News)

Disasters and accidents

- A major power outage in Pakistan leaves nearly 220 million people without electricity after a failure at the national power grid. Earlier this month, Prime Minister Shehbaz Sharif ordered a reduction in energy consumption as the country faces a severe energy crisis. (CNN) (Reuters)
- An Algerian Air Force Mi-171 helicopter crashes during a military exercise, killing three crew onboard in Ain Defla Province, Algeria. (MEHR)
- Two people are killed and two others are injured after a fire in a church in Beyoğlu, Istanbul, Turkey. (DailySabah)

International relations

- Sweden–Turkey relations
  - Enlargement of NATO, Sweden–NATO relations
    - Turkish President Recep Tayyip Erdoğan rules out Turkish support for Sweden's bid for NATO membership following the burning of a Quran outside the Turkish embassy in Stockholm by Rasmus Paludan and a series of pro-Kurdish demonstrations where protestors waved PKK flags. (AP)
- Estonia–Russia relations
  - Estonia announces the expulsion of the Russian ambassador in Tallinn Vladimir Lipayev to reciprocate Russia's expulsion of the Estonian ambassador in Moscow Margus Laidre due to a "downgrade" of relations. Both envoys will depart their respective assignments on February 7. (AP)
- Latvia–Russia relations
  - Latvia asks Russian ambassador Mikhail Vanin to leave the country by February 24 in "full solidarity" with Estonia. (Politico)

Law and crime

- Mass shootings in the United States
  - 2023 Monterey Park shooting
    - An eleventh person dies in the hospital from injuries sustained in Saturday's mass shooting in Monterey Park, California, United States. (Los Angeles Times)
  - 2023 Half Moon Bay shootings
    - Seven people are killed and one other person is injured in a shooting spree in Half Moon Bay, California, United States. A suspect is taken into custody afterwards. (San Francisco Chronicle)
- Aftermath of the 2020 Beirut explosion
  - Judge Tarek Bitar resumes his investigation into the explosion, 13 months after Hezbollah officials filed complaints against Bitar that prompted him to suspend the investigation. (AFP via Zawya)
- Eugenics in Japan
  - The Kumamoto district court [ja] orders the government to compensate two plaintiffs ¥22 million (US$170,000) worth of damages for their compulsory sterilization under the now-obsolete Eugenic Protection Act of 1948. (Kyodo News)

Science and technology

- A new study by seismologists at Peking University in Beijing says that Earth's inner core stopped rotating faster than the rest of the planet in 2009. (Nature) (New Scientist)

January 24, 2023 (2023-01-24) (Tuesday)

Armed conflicts and attacks

- 2022 Russian invasion of Ukraine
  - Eastern Ukraine campaign
    - Battle of Soledar
      - Two British aid workers are killed during a humanitarian evacuation from Soledar in Donetsk Oblast, Ukraine. (BBC News)
  - Germany–Ukraine relations
    - German Chancellor Olaf Scholz announces that Germany will send Leopard 2 main battle tanks to Ukraine, and will also allow other operators of the tanks, such as Poland, to send them to Ukraine. (Reuters)
- Sistan and Baluchestan insurgency
  - Two police officers are killed and a third is injured in an attack in Sistan and Baluchestan, Iran. (Al Arabiya)

Disasters and accidents

- List of earthquakes in 2023
  - At least one person is killed and two others are injured by a 5.9 magnitude earthquake in Bajura and Bajhang Districts, Nepal. (MyRepublica)
  - Three people are killed, twelve are missing and twelve are rescued after a building collapses in Lucknow, Uttar Pradesh, India, due to the earthquake in Nepal. (Reuters)
- 2023 Afghanistan cold snap
  - The death toll from two weeks of cold is 124 people and about 70,000 livestock, according to the government, the majority of whom lived in rural areas. (BBC News)
- Tornado outbreak of January 24–25, 2023
  - A tornado outbreak strikes the Gulf Coast of the United States, prompting the National Weather Service to issue a rare tornado emergency for areas east of Houston, Texas. (The New York Times)
- A Cessna 206 with six people on board goes missing in Isabela, Philippines. Rescue operations are being conducted. (Global China Daily)

Law and crime

- Three people are killed in a shooting at a Circle K store in Yakima, Washington, United States. The gunman later commits suicide in another location. (KNDO-TV) (CNN)

Politics and elections

- Corruption in Ukraine
  - Several senior Ukrainian officials, including deputy Head of the Office of the President of Ukraine Kyrylo Tymoshenko, four deputy ministers, and five regional governors, resign as a nationwide anti-corruption campaign is launched in Ukraine. (BBC News)

Science and technology

- Doomsday Clock
  - The Bulletin of the Atomic Scientists announces that the Doomsday Clock has been moved up to 90 seconds before midnight, largely due to the 2022 Russian invasion of Ukraine. (NPR) (CNN)

January 25, 2023 (2023-01-25) (Wednesday)

Armed conflicts and attacks

- 2022 Russian invasion of Ukraine
  - United States and the 2022 Russian invasion of Ukraine
    - President of the United States Joe Biden announces that the United States will send 31 M1 Abrams main battle tanks to Ukraine. (CNBC)
- Herder–farmer conflicts in Nigeria
  - Forty people are killed by an airstrike against Fulani people in Rukubi, Nasarawa State, Nigeria. The massacre is blamed on the army. (Africa News)
- 2022–2023 Democratic Republic of the Congo–Rwanda tensions
  - A DRC Air Force Sukhoi Su-25 is hit by anti-aircraft fire over the Rwandan border. The Rwandan government says that its forces took "defensive measures" against a plane that had "violated its airspace". (BBC News)
- Jihadist insurgency in Burkina Faso
  - France agrees to withdraw its 400 special forces personnel from Burkina Faso, following Saturday's mandate from the ruling military junta that France withdraw within one month. (BBC News)
- Algeciras church attacks
  - One person is killed and four others are injured when a man wielding a machete breaks into two churches in Algeciras, Andalusia, Spain. A 25-year-old Moroccan man is arrested. (El Mundo)
- Twelve people are injured when a bomb explodes in a market in Beni, North Kivu, Democratic Republic of the Congo, (AP)

Arts and culture

- UNESCO places the ruins of the Kingdom of Saba in modern-day Yemen, the historic center of Odesa, Ukraine, and the Rachid Karameh International Fair in Tripoli, Lebanon, on its list of World Heritage Sites in Danger. UNESCO cites ongoing conflicts and lack of funding due to the Lebanese liquidity crisis as the reasons for their inclusion. (NPR)

Business and economy

- 2021–2023 inflation surge
  - The Bank of Canada raises its benchmark interest rate to 4.5 percent, the highest since the 2007–2008 financial crisis, amid high levels of inflation and vacancies affecting the Canadian economy. (Financial Post)

Disasters and accidents

- A Hong Kong-registered ship carrying 22 people capsizes off the coast of Japan. Eight crew members are dead, 13 are rescued and two others still missing. (AFP via Barron's)
- A Philippine Air Force SF.260 training flight from Sangley Point Airport in Cavite City, Philippines, crashes into a paddy field in Pilar, Bataan, killing two people on board. (Rappler)

Health and environment

- NK News reports that the North Korean government has imposed a five-day lockdown in Pyongyang due to the spread of an unspecified respiratory infection. (AFP via ABS-CBN News)

International relations

- Iran and weapons of mass destruction
  - Nuclear program of Iran
    - International Atomic Energy Agency Director General Rafael Grossi says that Iran has now amassed enough material for "several nuclear weapons", and calls for new diplomatic efforts in order to prevent Iran from developing a nuclear bomb. (CNN)
- Iran–European Union relations, Iran–United Kingdom relations
  - Iran places sanctions on more than 30 UK and EU-affiliated individuals in a tit-for-tat response to a new round of sanctions by the European Union over the Mahsa Amini protests. Sanctioned individuals include UK Attorney General Victoria Prentis, UK Army Chief of Staff Sir Patrick Sanders, and three staff members of Charlie Hebdo. (RFE/RL)

Law and crime

- Brokstedt stabbing
  - Two people are killed and seven others are injured in a mass stabbing on a passenger train in Brokstedt, Steinburg, Schleswig-Holstein, Germany. (ITV)
- Human rights in Russia
  - The Moscow City Court orders the closure of the Moscow Helsinki Group, Russia's oldest human rights organization. (RFE/RL)

Politics and elections

- 2023 New Zealand Labour Party leadership election
  - Labour Party leader Chris Hipkins is sworn in as the 41st prime minister of New Zealand by Governor-General Cindy Kiro. (AFP via RFI)
- Cabinet of Borjana Krišto
  - The Parliamentary Assembly of Bosnia and Herzegovina votes 23–21 to approve the new Council of Ministers to be led by ethnic Croat former Federation President Borjana Krišto. (RFE/RL)

January 26, 2023 (2023-01-26) (Thursday)

Armed conflicts and attacks

- Russo-Ukrainian War
  - 2022 Russian invasion of Ukraine
    - 2022–2023 Russian strikes against Ukrainian infrastructure
      - Russia launches a wave of cruise missile and Shahed 129 drone strikes across Ukraine, targeting major cities and critical infrastructure, killing at least 11 people and injuring 11 others. Ukrainian general Valerii Zaluzhnyi says that at least 20 missiles have been intercepted over the capital Kyiv. (The Guardian)
- Somali Civil War
  - American military intervention in Somalia
    - A U.S. military raid in northern Somalia kills senior Islamic State member Bilal al-Sudani and ten other insurgents. No U.S. military casualties are reported in the operation, which was ordered by U.S. President Joe Biden. (NBC News)
- Israeli–Palestinian conflict
  - 2023 Jenin killings
    - Four Al-Qassam terrorists, three Islamic Jihad members and two Palestinian civilians are killed and 20 others are injured during a raid and subsequent gunfight by Israeli soldiers in Jenin, in the West Bank. In a separate raid in Al-Ram, a Palestinian man is killed and two others are injured by Israeli soldiers. (AP) (Al Jazeera)
- Aftermath of the 2022 Haitian crisis
  - Ten police officers are killed, one is critically injured and another is missing during a series of attacks in Port-au-Prince, Haiti, by the Gan Grif gang. (Al Jazeera)

Disasters and accidents

- At least 21 people are killed after a passenger bus en route from N'djamena to Abéché crashed into a truck near Oum Hadjer, Batha Est Department, Chad. (Reuters)

International relations

- Hong Kong–United States relations
  - U.S. President Joe Biden grants a two-year extension to the Deferred Enforced Departure immigration status of Hong Kong residents, citing increasing tensions between Hong Kong and mainland China. (AFP via GMA News Online)

Politics and elections

- 2023 Tokelauan general election
  - Tokelauans head to the polls to elect the members of the General Fono. (RNZ)

January 27, 2023 (2023-01-27) (Friday)

Armed conflicts and attacks

- Russo-Ukrainian War
  - 2022 Russian invasion of Ukraine
    - Eastern Ukraine campaign
      - Ukraine says that "fierce fighting" is underway in the east and northeast of the country as Russian troops try to break through Ukrainian defensive lines in Kharkiv, Donetsk, Luhansk and Zaporizhzhia Oblasts. (Reuters)
- Israeli–Palestinian conflict
  - Gaza–Israel conflict
    - Israeli Air Force jets launch airstrikes on an underground rocket manufacturing site, and a military base used by Hamas in the Gaza Strip, in response to rockets fired by Palestinian militants into southern Israel. (Reuters)
  - 2023 East Jerusalem synagogue shooting
    - Seven Israeli Jews are killed and three others are injured in a shooting at a synagogue in Jerusalem. The perpetrator is killed by police. (BBC News)
- Azerbaijan–Iran relations, Terrorism in Iran
  - Attack on the Azerbaijani embassy in Tehran
    - A guard is killed and two others are injured during a shooting at the Azerbaijani embassy in Tehran, Iran. The perpetrator is arrested. (Al Jazeera)
- Syrian civil war
  - Use of chemical weapons in the Syrian civil war
    - The Organisation for the Prohibition of Chemical Weapons concludes with "reasonable grounds" that the Douma chemical attack that occurred in 2018, was carried out by the Syrian military. (Al Jazeera)

Disasters and accidents

- 2023 North Island floods
  - Three people are killed and another person is missing during severe flash flooding in New Zealand's largest city Auckland. (Stuff)
- Environmental issues in Pakistan
  - At least 18 people have been killed in the past two weeks by toxic chemicals from factories in Karachi, Sindh, Pakistan. (Al Jazeera)
- A Russian Mi-8 helicopter of the "Rossiya" special flight squad [ru], which transports members of the government and armed forces, crashes at the Vnukovo Airport in Moscow. According to some reports there are injuries, with TASS reporting that pilot error is the main cause of the helicopter crash. (RTVI)
- Five people are killed as a result of landslides and floods in Manado, North Sulawesi, Indonesia. (CNN Indonesia)
- Two people are killed and seven others are injured after a suspected gas explosion destroys half a house in Katowice, Silesian Voivodeship, Poland. (AP)

Health and environment

- Rewilding
  - Cheetah reintroduction in India
    - South Africa agrees to send twelve cheetahs to India each year for the next eight to ten years to help secure a viable wild population. The Asiatic cheetah went extinct in India in the 1940s due to overhunting and habitat destruction. (BBC News)
- Western Australian radioactive capsule incident
  - A radioactive capsule is missing along a 1,400-kilometre stretch of highway in Western Australia. (ABC News Australia)

Law and crime

- Killing of Tyre Nichols
  - Tyre Nichols protests
    - Authorities in Memphis, Tennessee, United States, release footage of 29-year-old Tyre Nichols being violently assaulted by multiple Memphis Police Department officers during a traffic stop on January 7. (AP)
- Cannabis in Hong Kong
  - Hong Kong's Customs and Excise Department announces that all products containing cannabidiol will be banned as of February 1 and that the chemical will be classified in the same category as heroin and cocaine. (South China Morning Post)

Politics and elections

- 2023 Czech presidential election
  - Czechs head to the polls to vote in the second round of the presidential election. (BBC News)
- Greek wiretapping scandal of 2022
  - Prime Minister Kyriakos Mitsotakis survives a no-confidence vote called by former prime minister Alexis Tsipras over a wiretapping scandal. (AFP via The Sun)

January 28, 2023 (2023-01-28) (Saturday)

Armed conflicts and attacks

- Russo-Ukrainian War
  - 2022 Russian invasion of Ukraine
    - Battle of Donbas
      - Russia claims that a Ukrainian HIMARS missile strike on a hospital in Novoaidar, Luhansk Oblast, has killed 14 people and injured 24 others, including patients and medical staff. (Reuters)
    - Attacks on civilians in the 2022 Russian invasion of Ukraine
      - The Russian Air Force launches an airstrike on the city of Seredyna-Buda in Sumy Oblast, destroying a kindergarten and damaging nearby residential buildings. No casualties have been reported. The towns of Esman and Shalyhyne are also damaged by cross-border shelling. (Ukrinform)
- 2023 Iran drone attacks
  - The Iranian Defence Ministry says that a drone attack on a military plant in Isfahan, Iran, was "unsuccessful" with at least three drones shot down by air defenses. No casualties have been reported. (Reuters) (AP)
  - Explosions are reported at military sites and factories across Iran, including near the capital Tehran. Videos on social media appear to show explosions and large fires in the cities of Karaj, Dezful, and Tabriz. (Iran International)
  - An explosion occurs at an oil refinery in Azarshahr, East Azerbaijan province, according to Iranian media. (Urdu Point)
- Israeli–Palestinian conflict
  - Two Israelis are shot and critically injured by a 13-year-old Palestinian in East Jerusalem, in the West Bank and the attacker is shot and injured by one of his victims before being arrested. (Al Jazeera) The Times of Israel)

Business and economy

- British regional airline Flybe collapses into administration with 277 job losses, while 75,000 customers are affected by flight cancellations. (BBC News)

Disasters and accidents

- 2023 West Azerbaijan earthquake
  - Three people are killed and 816 others are injured by a magnitude 5.9 earthquake in Khoy, West Azerbaijan province, Iran. (Al Jazeera)
- Louisville, New York bus-truck crash
  - Six people are killed and three others are injured in a collision between a bus and a truck in Louisville, New York, United States. (NBC News)
- At least 24 people are killed when a bus plunges off a cliff in the El Alto District, Talara Province, Peru. (Reuters)

Law and crime

- Three people are killed inside a vehicle and four others are injured on the street during a mass shooting in the Beverly Crest neighborhood of Los Angeles, California, United States. (AP)

Politics and elections

- 2023 Czech presidential election
  - The Czech Statistical Office reports that former NATO Military Committee chair Petr Pavel has been elected president, defeating former prime minister Andrej Babiš with 58 percent of the votes. (AFP via France 24)

Sports

- 2023 Australian Open – Women's singles
  - Aryna Sabalenka defeats Elena Rybakina in the final, 4–6, 6–3, 6–4, to win the women's singles tennis title at the 2023 Australian Open in Melbourne, winning her first major singles title. (AFP via Deccan Herald)

January 29, 2023 (2023-01-29) (Sunday)

Armed conflicts and attacks

- Russo-Ukrainian War
  - 2022 Russian invasion of Ukraine
    - Eastern Ukraine campaign
      - Forces of the Wagner Group say that they have captured the village of Blahodatne, north of Bakhmut. However, Ukraine rejects the claim and says that it repelled the attack. (AFP via The Moscow Times)
    - Southern Ukraine campaign
      - Russian forces shell the city of Kherson, killing three people, injuring six others, and damaging a hospital, school, and bus station. (Reuters via U.S. News & World Report)
- Islamist insurgency in the Sahel
  - Jihadist insurgency in Burkina Faso
    - The governor of Comoé Province reports that 15 corpses, who were among 24 passengers of two minibuses that departed the provincial capital of Banfora when suspected jihadists hijacked the buses in Linguekoro and coerced the passengers to walk to Mangodara, were discovered near Linguekoro. The governor also reports that 15 other passengers had been abducted. (AFP via ABS-CBN News)
- Syrian civil war
  - Iran–Israel conflict during the Syrian civil war
    - Unidentified warplanes, suspected to be Israeli, strike a convoy of Iranian trucks that entered Syria from Iraq through the Al-Qa'im border crossing. At least six trucks are believed to have been destroyed. There are no immediate reports of casualties. (Times of Israel)
- Israeli–Palestinian conflict
  - An 18-year-old Palestinian man is shot dead by a group of Israeli civilians near the settlement of Kedumim, in the West Bank. In a separate incident, a Palestinian civilian home is set on fire by settlers. The occupants were not there at the time of the attack. (Al Jazeera)

Disasters and accidents

- 2023 Lasbela bus crash
  - At least 41 people are killed and two others are injured when a bus falls off a bridge and catches fire in Lasbela District, Balochistan, Pakistan. (Reuters)
- 2022–23 South-West Indian Ocean cyclone season
  - The death toll from Cyclone Cheneso's landfall in Madagascar has increased to 25, with 21 others still missing. (AFP via ABS-CBN News)
- Tanda Dam incident
  - Ten children are killed and eleven other people are injured when a boat capsizes at the Tanda Dam in Kohat District, Khyber Pakhtunkhwa, Pakistan. (AFP via Barron's)
- At least 22 people are killed and 21 injured when a bus crashes near Dassa-Zoumé, Collines Department, Benin. (TRT World)
- At least nine people are killed when a container falls from a truck onto a commercial bus in Lagos, Nigeria. (The Guardian Nigeria)
- An avalanche on Mount Norikura in Nagano Prefecture, Japan, kills two people, including American skier Kyle Smaine. (BBC News)

International relations

- Attack on the Azerbaijani Embassy in Tehran
  - Azerbaijan–Iran relations
    - Azerbaijan suspends diplomatic activities at its embassy in Tehran after accusing Iran of failing to ensure the security of its embassy staff. The Azerbaijani consulate general in Tabriz continues to operate routinely. (TASS)

Law and crime

- 2023 Gqeberha shooting
  - Eight people are killed and three others are injured in a mass shooting at a birthday party in Gqeberha, Eastern Cape, South Africa. (AFP via Hindustan Times)

Politics and elections

- 2023 Liechtenstein constitutional referendum
  - Voters in Liechtenstein reject a proposed ban on casinos. The proposal, which Prince Hans-Adam II opposed, was rejected by around 73 percent of voters. (Euronews)
- 2022–23 Tunisian parliamentary election
  - Tunisians head to the polls to elect the members of the third Assembly of the Representatives of the People in a run-off. The electoral board reports a voter turnout of 11.3 percent as most opposition parties boycott the election. (AFP via RFI)
- UK prime minister Rishi Sunak dismisses Nadhim Zahawi as chairman of the Conservative Party and minister without portfolio after Sunak's ethics adviser, Laurie Magnus, found that Zahawi had breached the Ministerial Code for failing to disclose a £5 million tax penalty payment to HM Revenue and Customs while serving as Chancellor of the Exchequer under former prime minister Boris Johnson. (BBC News)

Sports

- 2023 Australian Open – Men's singles
  - Novak Djokovic defeats Stefanos Tsitsipas in the final, 6–3, 7–6(7–4), 7–6(7–5), to win the men's singles tennis title at the 2023 Australian Open in Melbourne, tying him with Rafael Nadal for the most Grand Slams in men's tennis history with 22. (BBC Sport)
- 2023 World Men's Handball Championship
  - Denmark defeats France 34–29 in the final to win the 2023 World Men's Handball Championship in Stockholm, Sweden. Denmark becomes the first men's national handball team to win three consecutive world titles, having also won the 2019 and 2021 editions. (Reuters)

January 30, 2023 (2023-01-30) (Monday)

Armed conflicts and attacks

- Insurgency in Khyber Pakhtunkhwa
  - 2023 Peshawar mosque bombing
    - At least 100 people are killed and 225 others are injured when a suicide bomber detonates his explosive belt at a mosque in Peshawar, Khyber Pakhtunkhwa, Pakistan. The mosque is located inside a compound that includes the headquarters of the provincial police force and a counter-terrorism department. (Al Jazeera)
- Islamist insurgency in the Sahel
  - Jihadist insurgency in Burkina Faso
    - Ten police officers, two Volunteers for the Defense of the Homeland personnel, and a civilian are killed in a terrorist attack by at least 15 jihadists in Falagountou, Séno, while five other police officers are injured and ten people are missing. (AFP via ABS-CBN News)
- Syrian civil war
  - Fifteen people are injured after a bomb explodes near a bus carrying police officers near Khirbet Ghazaleh, Daraa Governorate, Syria. (AP)

Business and economy

- British sports-fashion retailer JD Sports says that the stored data of 10 million customers "may have been accessed" in a cyberattack, including names, addresses, email addresses, phone numbers, order details, and the final four digits of debit card numbers. (BBC News)

Health and environment

- COVID-19 pandemic
  - COVID-19 pandemic in the United States
    - The Biden administration announces that the United States will end its COVID-19 emergency proclamation on May 11 after being imposed for three years. (Forbes)
- Aging of China
  - The Chinese province of Sichuan announces the abolition of its three-child policy and the restrictions on birth registration for single parents on February 15, citing the country's population decline. (AFP via ABS-CBN News)

International relations

- Foreign relations of Kiribati
  - Prime Minister of Fiji Sitiveni Rabuka confirms that Kiribati will rejoin the Pacific Islands Forum after leaving the organization last year due to a dispute. (The Guardian)
- 2022–2023 Peruvian protests
  - The Organization of American States passes a resolution asking the government of Dina Boluarte to convene elections soon in an attempt to reduce the level of violence in Peru, which has already killed 65 people. (La Prensa Latina) (Infobae)

January 31, 2023 (2023-01-31) (Tuesday)

Armed conflicts and attacks

- Russo-Ukrainian War
  - 2022 Russian invasion of Ukraine
    - Foreign involvement in the 2022 Russian invasion of Ukraine
      - French Armed Forces Minister Sébastien Lecornu announces that France will send 12 additional CAESAR self-propelled howitzers to Ukraine, and could also train Ukrainian Air Force pilots to operate French fighter jets as part of their latest military support package. (Reuters)

Disasters and accidents

- Tanda Dam boat disaster
  - The death toll from a boat capsize at the Tanda Dam in Kohat District, Khyber Pakhtunkhwa, Pakistan, on 29 January increases to 51. (AFP via The Peninsula)

Health and environment

- COVID-19 pandemic
  - COVID-19 pandemic in the United States
    - COVID-19 pandemic in Illinois
      - Illinois Governor J. B. Pritzker announces that the state will end its COVID-19 emergency proclamation after three years beginning on May 11. (The State Journal-Register)
- The Namibian environment ministry announces that 61 black rhinoceros and 26 white rhinoceros were killed in the country in 2022 as a result of poaching, including 46 in Etosha National Park. (Al Jazeera)

International relations

- Pastoral visits of Pope Francis
  - Pope Francis begins his first papal visit to the Democratic Republic of the Congo. He will also visit South Sudan on the same trip. (AFP via RTHK)

Law and crime

- 2022–23 Salvadoran gang crackdown
  - The Salvadoran government opens the Terrorism Confinement Center, a prison with a capacity of 40,000, amidst a gang crackdown which has arrested over 62,000 people since March 2022. (Reuters)
- Killing of Tiba al-Ali
  - A YouTuber is killed in Iraq; her father confesses to the honour killing. (Al Jazeera)

Politics and elections

- Protests against Emmanuel Macron
  - 2023 French pension reform strikes
    - A second day of strikes and demonstrations occurs throughout France against the government's pension reform project, which proposes to increase the retirement age to 64. (BFMTV)

Sports

- 2022–23 Premier League
  - Chelsea F.C. sign Argentinian central midfielder Enzo Fernández from Primeira Liga club Benfica in a £106.8m deal to break the British football transfer fee record. (The Guardian)

◀January 2023▶
S | M | T | W | T | F | S
--- | --- | --- | --- | --- | --- | ---
1 | 2 | 3 | 4 | 5 | 6 | 7
8 | 9 | 10 | 11 | 12 | 13 | 14
15 | 16 | 17 | 18 | 19 | 20 | 21
22 | 23 | 24 | 25 | 26 | 27 | 28
29 | 30 | 31 |  |  |  |

Wikimedia Commons has media related to January 2023.
Retrieved from "https://en.wikipedia.org/w/index.php?title=Portal:Current_events/January_2023&oldid=1181703738"
Categories:

- 2023 by day
- January
- 2023
- Months in the 2020s
- Current events archives

Hidden categories:

- Pages with non-numeric formatnum arguments
- Interlanguage link template existing link